##  4.1 List of cookies and local storage objects
Below a list of the cookies and local storage objects generated from our platform.
Cookie Name | Description | Domain | Cookie / Local Storage | Type | Where is it used | Lifespan
---|---|---|---|---|---|---
_idp_authn_lc_key | Used to anonymously keep track of the user during the login flow |  {region}-svc.leanix.net |  COOKIE |  ESSENTIAL | IDP (SAP LeanIX) | Session
JSESSIONID | Used to anonymously keep track of the user during the login flow |  {region}-svc.leanix.net |  COOKIE |  ESSENTIAL | IDP (SAP LeanIX) | Session
_idp_session | Used to anonymously keep track of the current user session |  {region}-svc.leanix.net |  COOKIE |  ESSENTIAL | IDP (SAP LeanIX) | Session
_shibsession_{characters} | Used to anonymously keep track of the current user session |  {instance}.leanix.net |  COOKIE |  ESSENTIAL | IDP (SAP LeanIX) | Session
intercom-id-{characters} | Allows visitors to see any conversations they've had on Intercom chat support |  .leanix.net |  COOKIE |  FUNCTIONALITY | SAP LeanIX | 9 months
intercom-session-{characters} | Allows users to access their conversations |  .leanix.net |  COOKIE |  FUNCTIONALITY | SAP LeanIX | 1 week (from each log-in)
lxAccessToken:{workspace} | Holds JWT to authenticate as the user against SAP LeanIX services |  {instance}.leanix.net |  LOCAL STORAGE |  ESSENTIAL | SAP LeanIX | Unlimited
lxLastActivity:{workspace} | Used to implement auto-logout |  {instance}.leanix.net |  LOCAL STORAGE |  FUNCTIONALITY | SAP LeanIX | Unlimited
lxCurrentDashboard:{workspace} | Used to store what the current SAP LeanIX dashboard of the user is |  {instance}.leanix.net |  LOCAL STORAGE |  FUNCTIONALITY | SAP LeanIX | Unlimited


Note: SAP LeanIX maybe using additional Cookies as part of its website. Kindly refer to [https://www.leanix.net/en/privacy-policy![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fprivacy-policy "https://www.leanix.net/en/privacy-policy") for more details.
